aboutsummaryrefslogtreecommitdiff
path: root/src/rpc/util.cpp
diff options
context:
space:
mode:
authorAndrew Chow <achow101-github@achow101.com>2019-06-06 16:33:23 +0200
committerAndrew Chow <achow101-github@achow101.com>2019-07-09 16:20:18 -0400
commitd9becff4e13da8e182631baa79b9794c03d44434 (patch)
tree8b793f84bd72bd11b9753a1591f811fefafe1da2 /src/rpc/util.cpp
parenta913e3f2fbeb1352fc66f334d4f5f7332ea89ad7 (diff)
downloadbitcoin-d9becff4e13da8e182631baa79b9794c03d44434.tar.xz
scripted-diff: rename CBasicKeyStore to FillableSigningProvider
-BEGIN VERIFY SCRIPT- git grep -l "CBasicKeyStore" | xargs sed -i -e 's/CBasicKeyStore/FillableSigningProvider/g' -END VERIFY SCRIPT-
Diffstat (limited to 'src/rpc/util.cpp')
-rw-r--r--src/rpc/util.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/rpc/util.cpp b/src/rpc/util.cpp
index 65a1b39dd0..86f0dd24bb 100644
--- a/src/rpc/util.cpp
+++ b/src/rpc/util.cpp
@@ -131,8 +131,8 @@ CPubKey HexToPubKey(const std::string& hex_in)
return vchPubKey;
}
-// Retrieves a public key for an address from the given CBasicKeyStore
-CPubKey AddrToPubKey(CBasicKeyStore* const keystore, const std::string& addr_in)
+// Retrieves a public key for an address from the given FillableSigningProvider
+CPubKey AddrToPubKey(FillableSigningProvider* const keystore, const std::string& addr_in)
{
CTxDestination dest = DecodeDestination(addr_in);
if (!IsValidDestination(dest)) {
@@ -153,7 +153,7 @@ CPubKey AddrToPubKey(CBasicKeyStore* const keystore, const std::string& addr_in)
}
// Creates a multisig address from a given list of public keys, number of signatures required, and the address type
-CTxDestination AddAndGetMultisigDestination(const int required, const std::vector<CPubKey>& pubkeys, OutputType type, CBasicKeyStore& keystore, CScript& script_out)
+CTxDestination AddAndGetMultisigDestination(const int required, const std::vector<CPubKey>& pubkeys, OutputType type, FillableSigningProvider& keystore, CScript& script_out)
{
// Gather public keys
if (required < 1) {